AppFlyerProps class

Constructors

AppFlyerProps({required String afDevKey, required String appId, String? uninstallToken, bool? showDebug = false, dynamic onInstallConversionData(dynamic data)?})

Properties

afDevKey String
final
appId String
final
hashCode int
The hash code for this object.
no setterinherited
onInstallConversionData → dynamic Function(dynamic data)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDebug bool?
final
uninstallToken String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited