ExaAnalytics class

Implemented types

Constructors

ExaAnalytics({bool useFirebaseAnalytics = true, InngageProps? inngageProps, AppFlyerProps? appFlyerProps, AmplitudeProps? amplitudeProps})

Properties

amplitudeProps AmplitudeProps?
getter/setter pair
appFlyerProps AppFlyerProps?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inngageProps InngageProps?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useFirebaseAnalytics bool
final

Methods

amplitudeUpdate({AmplitudeProps? amplitudeProps}) → void
appsFlyerUpdate({AppFlyerProps? appFlyerProps}) → void
init({InngageProps? inngageProps, AppFlyerProps? appFlyerProps, AmplitudeProps? amplitudeProps}) → void
inngageUpdate({InngageProps? inngageProps}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDeepLinking(dynamic callback(dynamic)) Future<void>
override
setCurrentScreen({required String screenName, String? screenClassOverride}) Future<void>
Set current screen
override
setDefaultEventParameters({required Map<String, dynamic> parameters, List<UseAnalyticsOnly> listUseOnly = const [UseAnalyticsOnly.firebase]}) Future<void>
override
setLogEvent({required Map<String, dynamic> params, required String eventName, List<UseAnalyticsOnly>? listUseOnly}) Future<void>
Set log event
override
setLogUserId({required String id}) Future<void>
Set log user id
override
setLogUserProperties({required String name, String? value, Map<String, dynamic>? customFields, List<UseAnalyticsOnly>? listUseOnly}) Future<void>
Set log user properties
override
toString() String
A string representation of this object.
inherited
updateServerUninstallToken(String? uninstallToken) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited