BaseAnalytics class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDeepLinking(
dynamic callback(dynamic)) → void -
setCurrentScreen(
{required String screenName, String? screenClassOverride}) → Future< void> - Set current screen
-
setDefaultEventParameters(
{required Map< String, dynamic> parameters}) → Future<void> -
setLogEvent(
{required Map< String, Object> params, required String eventName}) → Future<void> - Set log event
-
setLogUserId(
{required String id}) → Future< void> - Set log user id
-
setLogUserProperties(
{required String name, String? value, Map< String, dynamic> ? customFields}) → Future<void> - Set log user properties
-
toString(
) → String -
A string representation of this object.
inherited
-
updateServerUninstallToken(
String? uninstallToken) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited