InngageProps class
Class of the params to the InngageAnalyticsImpl
Constructors
Properties
- appToken → String
-
final
- blockDeepLink → bool
-
final
-
customFields
→ Map<
String, dynamic> ? -
final
- email → String?
-
final
- firebaseListenCallback → Function?
-
final
- firebaseToken → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
-
final
- phoneNumber → String?
-
final
- requestAdvertiserId → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited